@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 1996-2006, 2010 Thorsten Kukuk, <kukuk@thkukuk.de>
+   Copyright (c) 1996-2006, 2010, 2011 Thorsten Kukuk, <kukuk@thkukuk.de>
    Copyright (c) 1994, 1995, 1996 Olaf Kirch, <okir@monad.swb.de>
 
    This file is part of the NYS YP Server.
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public
    License along with the NYS YP Server; see the file COPYING.  If
-   not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-   Cambridge, MA 02139, USA. */
+   not, write to the Free Software Foundation, Inc., 51 Franklin Street,
+   Suite 500, Boston, MA 02110-1335, USA. */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -372,12 +372,22 @@ main (int argc, char **argv)
 	}
       umask(0);
       i = open("/dev/null", O_RDWR);
+      if (i == -1)
+	{
+	  int err = errno;
+	  log_msg ("rpc.yppasswdd: open /dev/null failed: %s\n",
+		   strerror (err));
+	  exit (err);
+	}
+
+      /* two dups, we have stdin, stdout, stderr */
       if (dup(i) == -1)
 	{
 	  int err = errno;
 	  log_msg ("rpc.yppasswdd: dup failed: %s\n", strerror (err));
 	  exit (err);
 	}
+
       if (dup(i) == -1)
 	{
 	  int err = errno;
