@@ -1,4 +1,4 @@
-/* Copyright (c) 2003, 2004 Thorsten Kukuk
+/* Copyright (c) 2003, 2004, 2006 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    The YP Server is free software; you can redistribute it and/or
@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public
    License along with the YP Server; see the file COPYING. If
-   not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-   Cambridge, MA 02139, USA. */
+   not, write to the Free Software Foundation, Inc., 51 Franklin Street,
+   Suite 500, Boston, MA 02110-1335, USA. */
 
 #define _GNU_SOURCE
 
@@ -196,7 +196,14 @@ register_slp ()
 	}
       else
 	hp = gethostbyname (hostname);
-      hname = hp->h_name;
+      if (hp == NULL)
+	{
+	  log_msg ("Broken setup: cannot resolve %s, please fix",
+		   hostname);
+	  hname = hostname;
+	}
+      else
+	hname = hp->h_name;
 #endif
     }
 
