@@ -1,4 +1,4 @@
-/* Copyright (c) 1996-2010 Thorsten Kukuk
+/* Copyright (c) 1996-2011 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@thkukuk.de>
 
    The YP Server is free software; you can redistribute it and/or
@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public
    License along with the YP Server; see the file COPYING. If
-   not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-   Cambridge, MA 02139, USA. */
+   not, write to the Free Software Foundation, Inc., 51 Franklin Street,
+   Suite 500, Boston, MA 02110-1335, USA. */
 
 #define _GNU_SOURCE
 
@@ -411,6 +411,12 @@ main (int argc, char **argv)
 
       umask (0);
       i = open ("/dev/null", O_RDWR);
+      if (i == -1)
+	{
+	  log_msg ("opening /dev/null failed: %s\n", strerror (errno));
+	  exit (1);
+	}
+      /* two dups: stdin, stdout, stderr */
       if (dup (i) == -1)
 	{
 	  log_msg ("dup failed: %s\n", strerror (errno));
